@@ -1,15 +1,15 @@
-# 
+#
 # This file is part of CatalystX-ExtJS
-# 
+#
 # This software is Copyright (c) 2010 by Moritz Onken.
-# 
+#
 # This is free software, licensed under:
-# 
+#
 #   The (three-clause) BSD License
-# 
+#
 package CatalystX::Controller::ExtJS::Direct::API;
 BEGIN {
-  $CatalystX::Controller::ExtJS::Direct::API::VERSION = '1.101570';
+  $CatalystX::Controller::ExtJS::Direct::API::VERSION = '1.101670';
 }
 # ABSTRACT: API and router controller for Ext.Direct
 use Moose;
@@ -44,6 +44,7 @@ sub index { }
 
 sub src {
     my ($self, $c) = @_;
+    $c->res->content_type('application/javascript');
     $c->res->body( 'Ext.app.REMOTING_API = ' . $self->encoded_api . ';' );
 }
 
@@ -57,9 +58,9 @@ sub _build_api {
         my $meta       = $controller->meta;
         next
           unless ( $controller->can('is_direct') || $meta->does_role('CatalystX::Controller::ExtJS::Direct') );
-		my @methods;
+        my @methods;
         foreach my $method ( $controller->get_action_methods() ) {
-			next
+            next
               unless ( my $action = $controller->action_for( $method->name ) );
             next unless ( exists $action->attributes->{Direct} );
             my @routes =
@@ -104,15 +105,15 @@ sub router {
             }
         ];
         if ( $params->{extData} ) {
-			$reqs->[0]->{data} = JSON::Any->new->decode( delete $params->{extData} );
-		} else {
-			$reqs->[0]->{data} = [{%$params}];
-		}
+            $reqs->[0]->{data} = JSON::Any->new->decode( delete $params->{extData} );
+        } else {
+            $reqs->[0]->{data} = [{%$params}];
+        }
     }
-	
-	my @requests;
-	
-	foreach my $req (@$reqs) {
+    
+    my @requests;
+    
+    foreach my $req (@$reqs) {
         unless ( $req && $req->{action}
             && exists $routes->{ $req->{action} }
             && exists $routes->{ $req->{action} }->{ $req->{method} } )
@@ -120,51 +121,51 @@ sub router {
             $self->status_bad_request( $c, { message => 'method not found' } );
             return;
         }
-		 my $route = $routes->{ $req->{action} }->{ $req->{method} };
-		
-		push(@requests, $route->prepare_request($req));
+         my $route = $routes->{ $req->{action} }->{ $req->{method} };
+        
+        push(@requests, $route->prepare_request($req));
 
-	}
-	
+    }
+    
     my @res;
-	REQUESTS:
-	foreach my $req (@requests) {
-		$req->{data} = [$req->{data}] if(ref $req->{data} ne "ARRAY");
+    REQUESTS:
+    foreach my $req (@requests) {
+        $req->{data} = [$req->{data}] if(ref $req->{data} ne "ARRAY");
 
         my $route = $routes->{ $req->{action} }->{ $req->{method} };
-		my $params = @{$req->{data}} && ref $req->{data}->[-1] eq 'HASH' ? $req->{data}->[-1] : undef;
-    	my $body;
-		{
-			local $c->{response} = $c->response_class->new({});
-			local $c->{stash} = {};
-			local $c->{request} = $c->req;
-			
-			$c->req->parameters($params);
-			$c->req->body_parameters($params);
-			my %req = $route->request($req);
-			$c->req($c->request_class->new(%{$c->req}, %req));
+        my $params = @{$req->{data}} && ref $req->{data}->[-1] eq 'HASH' ? $req->{data}->[-1] : undef;
+        my $body;
+        {
+            local $c->{response} = $c->response_class->new({});
+            local $c->{stash} = {};
+            local $c->{request} = $c->req;
+            
+            $c->req->parameters($params);
+            $c->req->body_parameters($params);
+            my %req = $route->request($req);
+            $c->req($c->request_class->new(%{$c->req}, %req));
             eval {
                 $c->visit($route->build_url( $req->{data} ));
                 my $response = $c->res;
                 if ( $response->content_type eq 'application/json' ) {
                     (my $res_body = $response->body) =~ s/^\xEF\xBB\xBF//; # remove BOM
                     my $json = JSON::Any->new->decode( $res_body );
-					$json = $json->{data} if(ref $json eq 'HASH' && exists $json->{success} && exists $json->{data});
-					$body = $json;
-				} else {
-					$body = $response->body;
-				}
+                    $json = $json->{data} if(ref $json eq 'HASH' && exists $json->{success} && exists $json->{data});
+                    $body = $json;
+                } else {
+                    $body = $response->body;
+                }
             } or do {
-            	push(@res, { type => 'exception', tid => $req->{tid}, message => "$@".$c->response->body });
+                push(@res, { type => 'exception', tid => $req->{tid}, message => "$@".$c->response->body });
                 next REQUESTS;
-			};
-			
-			
-			
-		}
+            };
+            
+            
+            
+        }
 
         my $res = { map { $_ => $req->{$_} } qw(action method tid type) };
-	    $c->stash->{upload} = 1 if ( $req->{upload} );
+        $c->stash->{upload} = 1 if ( $req->{upload} );
         push( @res, { %$res, result => $body } );
 
     }
@@ -189,11 +190,11 @@ CatalystX::Controller::ExtJS::Direct::API - API and router controller for Ext.Di
 
 =head1 VERSION
 
-version 1.101570
+version 1.101670
 
 =head1 ACTIONS
 
-=head2 rpc
+=head2 router
 
 Every request to the API is going to hit this action, since the API's url will point to this action. 
 
@@ -202,7 +203,7 @@ You can change the url to this action via the class configuration.
 Example:
 
   package MyApp::Controller::API;
-  __PACKAGE__->config( action => { rpc => { Path => 'callme' } } );
+  __PACKAGE__->config( action => { router => { Path => 'callme' } } );
   1;
 
 The router is now available at C<< /api/callme >>.
@@ -221,17 +222,17 @@ Returns the API as a HashRef.
 
 Example:
 
-  {
-	url => '/api/router',
-	type => 'remote',
-	actions => {
-		Calc => {
-			methods => [
-					{ name => 'add', len => 2 },
-					{ name => 'subtract', len => 0 }
-				]
-		}
-	}
+ {
+    url => '/api/router',
+    type => 'remote',
+    actions => {
+        Calc => {
+            methods => [
+                    { name => 'add', len => 2 },
+                    { name => 'subtract', len => 0 }
+                ]
+        }
+    }
   }
 
 =head2 encoded_api
@@ -244,12 +245,12 @@ Example:
   Ext.Direct.addProvider(Ext.app.REMOTING_API);
   
   Calc.add(1, 3, function(provider, response) {
-	// process response
+    // process response
   });
 
 =head1 AUTHOR
 
-  Moritz Onken <onken@netcubed.de>
+Moritz Onken <onken@netcubed.de>
 
 =head1 COPYRIGHT AND LICENSE
 
