@@ -1,15 +1,15 @@
-# 
+#
 # This file is part of CatalystX-ExtJS
-# 
+#
 # This software is Copyright (c) 2010 by Moritz Onken.
-# 
+#
 # This is free software, licensed under:
-# 
+#
 #   The (three-clause) BSD License
-# 
+#
 package CatalystX::Controller::ExtJS::REST;
 BEGIN {
-  $CatalystX::Controller::ExtJS::REST::VERSION = '1.101560';
+  $CatalystX::Controller::ExtJS::REST::VERSION = '1.101670';
 }
 # ABSTRACT: RESTful interface to dbic objects
 
@@ -112,7 +112,9 @@ sub _extjs_config_builder {
         find_method => 'find',
     };
     my $self_config   = $self->config || {};
-    my $parent_config = $c->config->{'ControllerX::ExtJS::REST'} || {};
+    my $parent_config = $self->merge_config_hashes( 
+        $c->config->{'ControllerX::ExtJS::REST'} || {}, 
+        $c->config->{'ControllerX::Controller::ExtJS::REST'} || {} );
 
     # merge hashes with right hand precedence
     my $merged_config = $self->merge_config_hashes( $defaults, $self_config );
@@ -537,7 +539,7 @@ CatalystX::Controller::ExtJS::REST - RESTful interface to dbic objects
 
 =head1 VERSION
 
-version 1.101560
+version 1.101670
 
 =head1 SYNOPSIS
 
@@ -944,7 +946,7 @@ returned in a document with the C<Content-type> set to C<text/html>.
 
 =head1 AUTHOR
 
-  Moritz Onken <onken@netcubed.de>
+Moritz Onken <onken@netcubed.de>
 
 =head1 COPYRIGHT AND LICENSE
 
